<!-- some comment-->

---

# `jupyterlab-deck` examples

The contents of this folder are copied into the JupyterLite site.

```{hint}
If you got here from the main presentation, you can [go back](./README.ipynb#Multiple-Documents).
```

> This file is **also** a [basic deck](#Simple-Markdown-Decks) that can be viewed with
> the _Start Deck_ command.

---

## Simple Markdown Decks

- each `---` starts a new slide
  - including the first
- not-yet-appearing
  - no subslides
  - no fragments
  - no document styles
  - no live editing: see [workaround](#Live-Updating-Workaround)

---

## Future Work

- running code blocks
- styling with front/back matter

---

## Live Updating Workaround

- doesn't currently support this
  - well, sorta: right click and select _Show Markdown Editor_
  - <kbd>ctrl+shift+d</kbd>

> this may be improved in [future work](#Future-Work)
